/**A sparse, read-only array containing rules information for game entity types.

(For now only the highest level member attributes are documented here. Use the 'jsdebug' cheat

to see them all.)

These values are defined:

  * ```Body``` Droid bodies

  * ```Sensor``` Sensor turrets

  * ```ECM``` ECM (Electronic Counter-Measure) turrets

  * ```Propulsion``` Propulsions

  * ```Repair``` Repair turrets (not used, incidentally, for repair centers)

  * ```Construct``` Constructor turrets (eg for trucks)

  * ```Brain``` Brains

  * ```Weapon``` Weapon turrets

  * ```WeaponClass``` Defined weapon classes

  * ```Building``` Buildings*/
const Stats={
  "Body":[{"Id":""}],
  "Sensor":[{"Id":""}],
  "ECM":[{"Id":""}],
  "Propulsion":[{"Id":""}],
  "Repair":[{"Id":""}],
  "Construct":[{"Id":""}],
  "Brain":[{"Id":""}],
  "Weapon":[{"Id":""}],
  "WeaponClass":[""],
  "Building":[{"Id":""}]
  }

/**A special array containing per-player rules information for game entity types,

which can be written to in order to implement upgrades and other dynamic rules changes. Each item in the

array contains a subset of the sparse array of rules information in the ```Stats``` global.

These values are defined:

  * ```Body``` Droid bodies

  * ```Sensor``` Sensor turrets

  * ```Propulsion``` Propulsions

  * ```ECM``` ECM (Electronic Counter-Measure) turrets

  * ```Repair``` Repair turrets (not used, incidentally, for repair centers)

  * ```Construct``` Constructor turrets (eg for trucks)

  * ```Brain``` Brains

BaseCommandLimit: How many droids a commander can command. CommandLimitByLevel: How many extra droids

a commander can command for each of its rank levels. RankThresholds: An array describing how many

kills are required for this brain to level up to the next rank. To alter this from scripts, you must

set the entire array at once. Setting each item in the array will not work at the moment.

  * ```Weapon``` Weapon turrets

  * ```Building``` Buildings*/
const Upgrades={
  "Body":[],
  "Sensor":[],
  "Propulsion":[],
  "ECM":[],
  "Repair":[],
  "Construct":[],
  "Brain":[{
    "BaseCommandLimit":0,
    "CommandLimitByLevel":0,
    "RankThresholds":[0],
  }],
  "Weapon":[],
  "Building":[]
}

/**The type of alliances permitted in this game. It will be one of ```NO_ALLIANCES```, ```ALLIANCES```, ```ALLIANCES_UNSHARED``` or ```ALLIANCES_TEAMS```.*/
const alliancesType=0

/**The type of base that the game starts with. It will be one of ```CAMP_CLEAN```, ```CAMP_BASE``` or ```CAMP_WALLS```.*/
const baseType=0

/**If the current game is a challenge. (4.1.4+ only)*/
const challenge=true

/**A set of derrick starting positions on the current map. Each item in the set is an

object containing the x and y variables for a derrick.*/
const derrickPositions=[object0]

/**The currently set campaign difficulty, or the current AI's difficulty setting. It will be one of

```SUPEREASY``` (campaign only), ```EASY```, ```MEDIUM```, ```HARD``` or ```INSANE```.*/
const difficulty=0

/**The current game time. Updated before every invokation of a script.*/
const gameTime=0

/**A sparse array of group sizes. If a group has never been used, the entry in this array will

be undefined.*/
const groupSizes=[0]

/**The amount of game time without active play before a player should be considered "inactive". (0 = disable activity alerts / AFK check) (4.2.0+ only)*/
const idleTime=0

/**If the current game is a online multiplayer game or not. (3.2+ only)*/
const isMultiplayer=true

/**Height of map in tiles.*/
const mapHeight=0

/**The name of the current map.*/
const mapName='mapName'

/**Width of map in tiles.*/
const mapWidth=0

/**The number of active players in this game.*/
const maxPlayers=0

/**The player the script is currently running as.*/
const me=0

/**The current loaded mods.*/
const modList=[]

/**An array of information about the players in a game. Each item in the array is an object

containing the following variables:

  * ```difficulty``` (see ```difficulty``` global constant)

  * ```colour``` number describing the colour of the player

  * ```position``` number describing the position of the player in the game's setup screen

  * ```isAI``` whether the player is an AI (3.2+ only)

  * ```isHuman``` whether the player is human (3.2+ only)

  * ```name``` the name of the player (3.2+ only)

  * ```team``` the number of the team the player is part of*/
const playerData=[{
  "difficulty":0,
  "colour":0,
  "position":0,
  "isAI":true,
  "isHuman":true,
  "name":"name",
  "team":0
}]

/**The power level set for this game.*/
const powerType=0

/**Index of scavenger player. (3.2+ only)*/
const scavengerPlayer=0

/**Whether or not scavengers are activated in this game, and, if so, which type.*/
const scavengers=true

/**Base name of the script that is running.*/
const scriptName='scriptName'

/**Base path of the script that is running.*/
const scriptPath='scriptPath'

/**The player controlled by the client on which the script runs.*/
const selectedPlayer=0

/**An array of player start positions on the current map. Each item in the array is an

object containing the x and y variables for a player start position.*/
const startPositions=[object0]

/**The area name of the map.*/
const tilesetType='tilesetType'

/**Current version of the game, set in *major.minor* format.*/
const version='version'

/** A two-dimensional array of static information about the map tiles in a game. Each item in MapTiles[y][x] is an object
 * containing the following variables:
 */
const MapTiles=[[{
  "terrainType":0,
  "height":0,
  "hoverContinent":true,
  "limitedContinent":true
}]]
